###############################
Filtering frequency-domain data
###############################

Frequency-domain data (a :class:`~gwpy.spectrum.Spectrum` or a :class:`~gwpy.spectrogram.Spectrogram`) can be filtered using an arbitrary filter using the :meth:`filter` methods of those objects:

.. currentmodule:: gwpy.spectrum

.. autosummary::

   Spectrum.filter

.. currentmodule:: gwpy.spectrogram

.. autosummary::

   Spectrogram.filter
